@@ -1,5 +1,3 @@
-from pathlib import Path
-
 """
 MCP Gateway command implementation for claude-mpm.
 
@@ -11,11 +9,9 @@ that dispatches to specific subcommand handlers, maintaining consistency
 with other command modules like agents.py and memory.py.
 """
 
-import asyncio
 import json
 import sys
 from pathlib import Path
-from typing import Any, Dict, List, Optional
 
 from ...constants import MCPCommands
 from ...core.logger import get_logger
@@ -38,9 +34,10 @@ def manage_mcp(args):
     logger = get_logger("cli.mcp")
 
     # First check if MCP package is installed for any command
-    try:
-        import mcp
-    except ImportError:
+    import importlib.util
+
+    mcp_spec = importlib.util.find_spec("mcp")
+    if not mcp_spec:
         if args.mcp_command != MCPCommands.INSTALL.value:
             print("\nMCP package is not installed.", file=sys.stderr)
             print("Please install it first:", file=sys.stderr)
@@ -70,7 +67,7 @@ def manage_mcp(args):
                 MCPGateway = None
             else:
                 print(
-                    f"\nError: MCP Gateway services not fully available",
+                    "\nError: MCP Gateway services not fully available",
                     file=sys.stderr,
                 )
                 print(f"Details: {e}", file=sys.stderr)
@@ -118,7 +115,12 @@ def manage_mcp(args):
 
 
 def _show_status(
-    args, logger, MCPConfiguration, MCPServiceRegistry, ToolRegistry, MCPGateway
+    args,
+    logger,
+    MCPConfiguration,
+    MCPServiceRegistry,
+    ToolRegistry,
+    MCPGateway,
 ):
     """
     Show MCP Gateway status when no subcommand is provided.
@@ -133,11 +135,12 @@ def _show_status(
     print("=" * 50)
 
     # Check if MCP package is installed
-    try:
-        import mcp
+    import importlib.util
 
+    mcp_spec = importlib.util.find_spec("mcp")
+    if mcp_spec:
         print("✅ MCP package installed")
-    except ImportError:
+    else:
         print("❌ MCP package not installed")
         print("   Run: claude-mpm mcp install")
         return 1
@@ -148,7 +151,7 @@ def _show_status(
     if config_path.exists():
         print(f"   Config file: {config_path}")
         try:
-            with open(config_path) as f:
+            with config_path.open() as f:
                 config = json.load(f)
                 if "servers" in config:
                     print(f"   Configured servers: {len(config.get('servers', {}))}")
@@ -168,7 +171,7 @@ def _show_status(
     if claude_config.exists():
         print(f"\n🖥️  Claude Code Config: {claude_config}")
         try:
-            with open(claude_config) as f:
+            with claude_config.open() as f:
                 config = json.load(f)
                 mcp_servers = config.get("mcpServers", {})
                 if "claude-mpm" in mcp_servers:
@@ -185,10 +188,10 @@ def _show_status(
     # Show available tools count
     if ToolRegistry:
         try:
-            registry = ToolRegistry()
+            ToolRegistry()
             # Don't initialize fully, just check
-            print(f"\n🔧 Tools: Check with 'claude-mpm mcp tools'")
-        except:
+            print("\n🔧 Tools: Check with 'claude-mpm mcp tools'")
+        except Exception:
             print("\n🔧 Tools: Registry not available")
 
     print("\n💡 Available Commands:")
