@@ -527,11 +527,11 @@ class MCPExternalServicesSetup:
         module_name = service_info.get("module_name", service_name.replace("-", "_"))
         if not self._check_python_package(module_name):
             print(f"   ⚠️ Python package {service_info['package_name']} not installed")
-            print(f"   ℹ️ Installing {service_info['package_name']}...")
+            print(f"   [INFO]️ Installing {service_info['package_name']}...")
             if not self._install_python_package(service_info["package_name"]):
                 print(f"   ❌ Failed to install {service_info['package_name']}")
                 print(
-                    f"   ℹ️ Install manually with: pip install {service_info['package_name']}"
+                    f"   [INFO]️ Install manually with: pip install {service_info['package_name']}"
                 )
                 return False
 
@@ -621,7 +621,7 @@ class MCPExternalServicesSetup:
         """
         try:
             if config_path.exists():
-                with open(config_path) as f:
+                with config_path.open() as f:
                     config = json.load(f)
                     # Ensure mcpServers key exists
                     if "mcpServers" not in config:
@@ -664,7 +664,7 @@ class MCPExternalServicesSetup:
                 print(f"   📁 Created backup: {backup_path}")
 
             # Write configuration with proper formatting
-            with open(config_path, "w") as f:
+            with config_path.open("w") as f:
                 json.dump(config, f, indent=2)
                 f.write("\n")  # Add newline at end of file
 
@@ -830,7 +830,7 @@ class MCPExternalServicesSetup:
 
         if mcp_config_path.exists():
             try:
-                with open(mcp_config_path) as f:
+                with mcp_config_path.open() as f:
                     mcp_config = json.load(f)
                 print(f"\n📁 Project MCP config: {mcp_config_path}")
             except Exception:
