@@ -13,28 +13,28 @@ from .argument_patterns import (
     add_memory_arguments,
     add_output_arguments,
 )
-from .command_base import AgentCommand, BaseCommand, CommandResult, MemoryCommand
+from .base_command import AgentCommand, BaseCommand, CommandResult, MemoryCommand
 from .error_handling import CLIErrorHandler, handle_cli_errors
 from .output_formatters import OutputFormatter, format_output
 
 __all__ = [
+    # Command base
+    "AgentCommand",
+    "BaseCommand",
+    # Error handling
+    "CLIErrorHandler",
+    "CommandResult",
     # Argument patterns
     "CommonArguments",
+    "MemoryCommand",
+    # Output formatting
+    "OutputFormatter",
     "add_agent_arguments",
     "add_common_arguments",
     "add_config_arguments",
     "add_logging_arguments",
     "add_memory_arguments",
     "add_output_arguments",
-    # Command base
-    "AgentCommand",
-    "BaseCommand",
-    "CommandResult",
-    "MemoryCommand",
-    # Error handling
-    "CLIErrorHandler",
-    "handle_cli_errors",
-    # Output formatting
-    "OutputFormatter",
     "format_output",
+    "handle_cli_errors",
 ]
