@@ -44,6 +44,7 @@ class CLICommands(str, Enum):
     MCP = "mcp"
     DOCTOR = "doctor"
     DASHBOARD = "dashboard"
+    UPGRADE = "upgrade"
 
     def with_prefix(self, prefix: CLIPrefix = CLIPrefix.MPM) -> str:
         """Get command with prefix."""
@@ -140,6 +141,7 @@ class MCPCommands(str, Enum):
     TEST = "test"
     CONFIG = "config"
     SERVER = "server"
+    EXTERNAL = "external"
 
 
 class TicketCommands(str, Enum):
