@@ -14,7 +14,7 @@ This module provides:
 import contextlib
 import warnings
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
@@ -379,7 +379,7 @@ class AgentRegistryAdapter:
         }
 
         nickname = nicknames.get(agent_name, agent_name.title())
-        today = datetime.now().strftime("%Y-%m-%d")
+        today = datetime.now(timezone.utc).strftime("%Y-%m-%d")
 
         return f"""**{nickname}**: {task}
 
