@@ -17,7 +17,7 @@ import threading
 import time
 from collections import defaultdict, deque
 from dataclasses import dataclass, field
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from enum import Enum
 from typing import Any, Deque, Dict, List, Optional
 
@@ -97,11 +97,9 @@ class CircuitBreaker:
             return True
         if self.state == CircuitState.OPEN:
             # Check if recovery timeout has passed
-            if (
-                self.last_failure_time
-                and datetime.now() - self.last_failure_time
-                > timedelta(seconds=self.recovery_timeout)
-            ):
+            if self.last_failure_time and datetime.now(
+                timezone.utc
+            ) - self.last_failure_time > timedelta(seconds=self.recovery_timeout):
                 self.state = CircuitState.HALF_OPEN
                 self.logger.info(
                     "Circuit breaker transitioning to HALF_OPEN for testing"
@@ -127,7 +125,7 @@ class CircuitBreaker:
     def record_failure(self):
         """Record failed execution."""
         self.failure_count += 1
-        self.last_failure_time = datetime.now()
+        self.last_failure_time = datetime.now(timezone.utc)
 
         if self.state == CircuitState.HALF_OPEN:
             # Test failed, go back to OPEN
@@ -184,7 +182,7 @@ class SocketIOConnectionPool:
         # Health monitoring
         self.health_thread = None
         self.health_running = False
-        self.last_health_check = datetime.now()
+        self.last_health_check = datetime.now(timezone.utc)
 
         # Server configuration
         self.server_url = None
@@ -311,7 +309,7 @@ class SocketIOConnectionPool:
                         self.server_url = f"http://localhost:{port}"
                         self.logger.debug(f"Detected Socket.IO server on port {port}")
                         return
-            except:
+            except Exception:
                 continue
 
         # Fall back to default
@@ -375,7 +373,7 @@ class SocketIOConnectionPool:
                 # Check if connection is still valid
                 for conn_id, stats in self.connection_stats.items():
                     if stats.is_connected:
-                        stats.last_used = datetime.now()
+                        stats.last_used = datetime.now(timezone.utc)
                         return client
 
             # Create new connection if under limit
@@ -581,7 +579,7 @@ class SocketIOConnectionPool:
                     loop.stop()
                     loop.run_until_complete(loop.shutdown_asyncgens())
                     loop.close()
-                except:
+                except Exception:
                     pass
 
     async def _connect_client(self, client: socketio.AsyncClient):
@@ -592,13 +590,13 @@ class SocketIOConnectionPool:
 
             # 2-second timeout for connection
             await asyncio.wait_for(
-                client.connect(self.server_url, auth={"token": "dev-token"}, wait=True),
+                client.connect(self.server_url, wait=True),
                 timeout=2.0,
             )
 
-        except asyncio.TimeoutError:
+        except asyncio.TimeoutError as e:
             self.logger.debug("Socket.IO connection timeout")
-            raise TimeoutError("Socket.IO connection timeout")
+            raise TimeoutError("Socket.IO connection timeout") from e
         except Exception as e:
             self.logger.debug(f"Client connection failed: {e}")
             raise
@@ -623,7 +621,7 @@ class SocketIOConnectionPool:
                 self._check_connections_health()
 
                 # Update last health check time
-                self.last_health_check = datetime.now()
+                self.last_health_check = datetime.now(timezone.utc)
 
             except Exception as e:
                 self.logger.error(f"Health monitor error: {e}")
@@ -655,7 +653,9 @@ class SocketIOConnectionPool:
                     continue
 
                 # 3. Connection idle for too long (>5 minutes)
-                idle_time = (datetime.now() - stats.last_used).total_seconds()
+                idle_time = (
+                    datetime.now(timezone.utc) - stats.last_used
+                ).total_seconds()
                 if idle_time > 300 and conn_id not in [
                     id for id, _ in enumerate(self.available_connections)
                 ]:
@@ -734,8 +734,8 @@ class SocketIOConnectionPool:
     def emit(self, event: str, data: Dict[str, Any]) -> bool:
         """Emit an event through the connection pool.
 
-        This method provides compatibility for the legacy emit() interface
-        by mapping to the modern emit_event() method with appropriate defaults.
+        This method provides compatibility for the legacy emit() interface.
+        For critical hook events, we use direct emission to avoid batching delays.
 
         Args:
             event: Event name (e.g., "claude_event")
@@ -747,10 +747,42 @@ class SocketIOConnectionPool:
         if not SOCKETIO_AVAILABLE or not self._running:
             return False
 
+        # For critical claude_event, use direct emission to avoid batching delays
+        if event == "claude_event":
+            return self._emit_direct(event, data)
+
         # Map to the modern emit_event method using default namespace
         self.emit_event("/", event, data)
         return True
 
+    def _emit_direct(self, event: str, data: Dict[str, Any]) -> bool:
+        """Emit an event directly without batching.
+
+        This is used for critical events that need immediate delivery.
+        """
+        try:
+            # Create a synchronous client for direct emission
+            import socketio
+
+            client = socketio.Client(logger=False, engineio_logger=False)
+
+            # Quick connect, emit, and disconnect
+            client.connect(self.server_url, wait=True, wait_timeout=1.0)
+            client.emit(event, data)
+            client.disconnect()
+
+            # Update stats
+            for stats in self.connection_stats.values():
+                stats.events_sent += 1
+                break
+
+            return True
+        except Exception as e:
+            self.logger.debug(f"Direct emit failed: {e}")
+            # Fall back to batched emission
+            self.emit_event("/", event, data)
+            return True
+
     def get_stats(self) -> Dict[str, Any]:
         """Get connection pool statistics."""
         with self.pool_lock:
