@@ -771,4 +771,7 @@ class AgentHierarchy {
 
 // ES6 Module export
 export { AgentHierarchy };
-export default AgentHierarchy;
\ No newline at end of file
+export default AgentHierarchy;
+
+// Make AgentHierarchy globally available for dist/dashboard.js
+window.AgentHierarchy = AgentHierarchy;
\ No newline at end of file
