@@ -1,13 +1,13 @@
 /**
  * Agent Inference Module
- * 
+ *
  * Handles agent inference and processing logic for determining whether events
  * originate from the main agent or subagents based on event patterns and context.
- * 
+ *
  * WHY: Separated from main dashboard to isolate complex agent inference logic
  * that analyzes event patterns to determine agent context. This provides better
  * maintainability and testability for a critical feature.
- * 
+ *
  * DESIGN DECISION: This module maintains its own state for inference tracking
  * but relies on the event viewer for source data, keeping clear separation of
  * concerns while enabling delegation context tracking across events.
@@ -15,7 +15,7 @@
 class AgentInference {
     constructor(eventViewer) {
         this.eventViewer = eventViewer;
-        
+
         // Agent inference state tracking
         this.state = {
             // Track current subagent delegation context
@@ -27,9 +27,13 @@ class AgentInference {
             // PM delegation tracking for unique instance views
             pmDelegations: new Map(), // delegation_id -> delegation context
             // Map of agent events to their PM delegation
-            agentToDelegation: new Map() // agent_name -> delegation_id
+            agentToDelegation: new Map(), // agent_name -> delegation_id
+            // Track orphan subagent events (SubagentStart without PM Task)
+            orphanSubagents: new Map(), // event_index -> orphan context
+            // Track SubagentStart events for orphan detection
+            subagentStartEvents: new Map() // agent_name -> array of start events
         };
-        
+
         console.log('Agent inference system initialized');
     }
 
@@ -43,7 +47,9 @@ class AgentInference {
             sessionAgents: new Map(),
             eventAgentMap: new Map(),
             pmDelegations: new Map(),
-            agentToDelegation: new Map()
+            agentToDelegation: new Map(),
+            orphanSubagents: new Map(),
+            subagentStartEvents: new Map()
         };
     }
 
@@ -60,12 +66,12 @@ class AgentInference {
         const eventType = event.hook_event_name || data.hook_event_name || event.type || '';
         const subtype = event.subtype || data.subtype || '';
         const toolName = event.tool_name || data.tool_name || '';
-        
+
         // Debug logging for first few events to understand structure
         if (Math.random() < 0.1) {
             console.log('Agent inference debug:', {
-                eventType, 
-                toolName, 
+                eventType,
+                toolName,
                 hasData: !!event.data,
                 dataKeys: Object.keys(data),
                 eventKeys: Object.keys(event),
@@ -73,7 +79,7 @@ class AgentInference {
                 subagentType: event.subagent_type || data.subagent_type
             });
         }
-        
+
         // Direct event detection (highest confidence) - from design doc
         if (eventType === 'SubagentStop' || subtype === 'subagent_stop') {
             const agentName = this.extractAgentNameFromEvent(event);
@@ -92,7 +98,7 @@ class AgentInference {
                 reason: 'SubagentStop event'
             };
         }
-        
+
         if (eventType === 'Stop' || subtype === 'stop') {
             return {
                 type: 'main_agent',
@@ -101,7 +107,7 @@ class AgentInference {
                 reason: 'Stop event'
             };
         }
-        
+
         // Tool-based detection (high confidence) - from design doc
         if (toolName === 'Task') {
             const agentName = this.extractSubagentTypeFromTask(event);
@@ -120,7 +126,7 @@ class AgentInference {
                 };
             }
         }
-        
+
         // Hook event pattern analysis (high confidence)
         if (eventType === 'PreToolUse' && toolName === 'Task') {
             const agentName = this.extractSubagentTypeFromTask(event);
@@ -133,7 +139,7 @@ class AgentInference {
                 };
             }
         }
-        
+
         // Session pattern analysis (medium confidence) - from design doc
         if (sessionId) {
             const sessionLower = sessionId.toLowerCase();
@@ -146,11 +152,11 @@ class AgentInference {
                 };
             }
         }
-        
+
         // Agent type field analysis - check multiple possible locations
         const agentType = event.agent_type || data.agent_type || event.agent_id || data.agent_id;
         const subagentType = event.subagent_type || data.subagent_type;
-        
+
         if (subagentType && subagentType !== 'unknown') {
             return {
                 type: 'subagent',
@@ -159,7 +165,7 @@ class AgentInference {
                 reason: 'subagent_type field'
             };
         }
-        
+
         if (agentType && agentType !== 'unknown' && agentType !== 'main') {
             return {
                 type: 'subagent',
@@ -168,7 +174,7 @@ class AgentInference {
                 reason: 'agent_type field'
             };
         }
-        
+
         // Check for delegation_details from hook handler
         if (data.delegation_details?.agent_type) {
             return {
@@ -178,12 +184,12 @@ class AgentInference {
                 reason: 'delegation_details'
             };
         }
-        
+
         // Check if this looks like a Hook event from Socket.IO
         if (event.type && event.type.startsWith('hook.')) {
             // Extract the hook type
             const hookType = event.type.replace('hook.', '');
-            
+
             // Handle SubagentStart events
             if (hookType === 'subagent_start' || (data.hook_event_name === 'SubagentStart')) {
                 const rawAgentName = data.agent_type || data.agent_id || 'Subagent';
@@ -199,7 +205,7 @@ class AgentInference {
                     reason: 'Socket.IO hook SubagentStart'
                 };
             }
-            
+
             // Handle SubagentStop events
             if (hookType === 'subagent_stop' || (data.hook_event_name === 'SubagentStop')) {
                 const rawAgentName = data.agent_type || data.agent_id || 'Subagent';
@@ -211,7 +217,7 @@ class AgentInference {
                 };
             }
         }
-        
+
         // Default to main agent (from design doc)
         return {
             type: 'main_agent',
@@ -228,7 +234,7 @@ class AgentInference {
      */
     normalizeAgentName(agentName) {
         if (!agentName) return 'Unknown';
-        
+
         // Agent name mapping from raw format to display format
         const agentNameMap = {
             'engineer': 'Engineer Agent',
@@ -242,13 +248,13 @@ class AgentInference {
             'test_integration': 'Test Integration Agent',
             'pm': 'PM Agent'
         };
-        
+
         // Check if we have a direct mapping
         const normalized = agentNameMap[agentName.toLowerCase()];
         if (normalized) {
             return normalized;
         }
-        
+
         // If no direct mapping, apply basic formatting:
         // Convert underscore to space, capitalize words, and add "Agent" if not present
         let formatted = agentName
@@ -256,12 +262,12 @@ class AgentInference {
             .split(' ')
             .map(word => word.charAt(0).toUpperCase() + word.slice(1).toLowerCase())
             .join(' ');
-        
+
         // Add "Agent" suffix if not already present
         if (!formatted.toLowerCase().includes('agent')) {
             formatted += ' Agent';
         }
-        
+
         return formatted;
     }
 
@@ -272,7 +278,7 @@ class AgentInference {
      */
     extractSubagentTypeFromTask(event) {
         let rawAgentName = null;
-        
+
         // Check tool_parameters directly
         if (event.tool_parameters?.subagent_type) {
             rawAgentName = event.tool_parameters.subagent_type;
@@ -289,7 +295,7 @@ class AgentInference {
         else if (event.tool_input?.subagent_type) {
             rawAgentName = event.tool_input.subagent_type;
         }
-        
+
         // Normalize the agent name before returning
         return rawAgentName ? this.normalizeAgentName(rawAgentName) : null;
     }
@@ -302,13 +308,13 @@ class AgentInference {
     extractAgentNameFromEvent(event) {
         // Priority order based on reliability from design doc
         const data = event.data || {};
-        
+
         // 1. Task tool subagent_type (highest priority)
         if (event.tool_name === 'Task' || data.tool_name === 'Task') {
             const taskAgent = this.extractSubagentTypeFromTask(event);
             if (taskAgent) return taskAgent;
         }
-        
+
         // 2. Direct subagent_type field
         if (event.subagent_type && event.subagent_type !== 'unknown') {
             return this.normalizeAgentName(event.subagent_type);
@@ -316,12 +322,12 @@ class AgentInference {
         if (data.subagent_type && data.subagent_type !== 'unknown') {
             return this.normalizeAgentName(data.subagent_type);
         }
-        
+
         // 2.5. Check delegation_details
         if (data.delegation_details?.agent_type && data.delegation_details.agent_type !== 'unknown') {
             return this.normalizeAgentName(data.delegation_details.agent_type);
         }
-        
+
         // 3. Agent type fields (but not 'main' or 'unknown')
         if (event.agent_type && !['main', 'unknown'].includes(event.agent_type)) {
             return this.normalizeAgentName(event.agent_type);
@@ -329,7 +335,7 @@ class AgentInference {
         if (data.agent_type && !['main', 'unknown'].includes(data.agent_type)) {
             return this.normalizeAgentName(data.agent_type);
         }
-        
+
         // 4. Agent ID field as fallback
         if (event.agent_id && !['main', 'unknown'].includes(event.agent_id)) {
             return this.normalizeAgentName(event.agent_id);
@@ -337,16 +343,16 @@ class AgentInference {
         if (data.agent_id && !['main', 'unknown'].includes(data.agent_id)) {
             return this.normalizeAgentName(data.agent_id);
         }
-        
+
         // 5. Other fallbacks
         if (event.agent && event.agent !== 'unknown') {
             return this.normalizeAgentName(event.agent);
         }
-        
+
         if (event.name && event.name !== 'unknown') {
             return this.normalizeAgentName(event.name);
         }
-        
+
         // Default fallback
         return 'Unknown';
     }
@@ -357,37 +363,39 @@ class AgentInference {
      */
     processAgentInference() {
         const events = this.eventViewer.events;
-        
+
         // Reset inference state
         this.state.currentDelegation = null;
         this.state.sessionAgents.clear();
         this.state.eventAgentMap.clear();
         this.state.pmDelegations.clear();
         this.state.agentToDelegation.clear();
-        
+        this.state.orphanSubagents.clear();
+        this.state.subagentStartEvents.clear();
+
         console.log('Processing agent inference for', events.length, 'events');
-        
+
         // Early return if no events
         if (!events || events.length === 0) {
             console.log('No events to process for agent inference');
             return;
         }
-        
+
         // Process events chronologically to track delegation context
         events.forEach((event, index) => {
             let finalAgent; // Declare outside try-catch to ensure scope availability
-            
+
             try {
                 const inference = this.inferAgentFromEvent(event);
                 const sessionId = event.session_id || event.data?.session_id || 'default';
-                
+
                 // Determine agent for this event based on context
                 finalAgent = inference;
-                
+
                 // If we're in a delegation context and this event doesn't have high confidence agent info,
                 // inherit from delegation context
-                if (this.state.currentDelegation && 
-                    inference.confidence === 'default' && 
+                if (this.state.currentDelegation &&
+                    inference.confidence === 'default' &&
                     sessionId === this.state.currentDelegation.sessionId) {
                     finalAgent = {
                         type: 'subagent',
@@ -396,7 +404,26 @@ class AgentInference {
                         reason: 'inherited from delegation context'
                     };
                 }
+
+                // Track SubagentStart events for orphan detection
+                const hookEventName = event.hook_event_name || event.data?.hook_event_name || '';
+                const isSubagentStart = hookEventName === 'SubagentStart' || 
+                                       event.type === 'hook.subagent_start' ||
+                                       event.subtype === 'subagent_start';
                 
+                if (isSubagentStart && inference.type === 'subagent') {
+                    // Track this SubagentStart event
+                    if (!this.state.subagentStartEvents.has(inference.agentName)) {
+                        this.state.subagentStartEvents.set(inference.agentName, []);
+                    }
+                    this.state.subagentStartEvents.get(inference.agentName).push({
+                        eventIndex: index,
+                        event: event,
+                        timestamp: event.timestamp,
+                        sessionId: sessionId
+                    });
+                }
+
                 // Track delegation boundaries and PM delegations
                 if (event.tool_name === 'Task' && inference.type === 'subagent') {
                     // Start of subagent delegation - create PM delegation entry
@@ -411,10 +438,10 @@ class AgentInference {
                         timestamp: event.timestamp,
                         agentEvents: [] // Collect all events from this agent
                     };
-                    
+
                     this.state.pmDelegations.set(delegationId, pmDelegation);
                     this.state.agentToDelegation.set(inference.agentName, delegationId);
-                    
+
                     this.state.currentDelegation = {
                         agentName: inference.agentName,
                         sessionId: sessionId,
@@ -427,18 +454,18 @@ class AgentInference {
                     // End of subagent delegation
                     if (this.state.currentDelegation) {
                         this.state.currentDelegation.endIndex = index;
-                        
+
                         // Update PM delegation end point
                         const pmDelegation = this.state.pmDelegations.get(this.state.currentDelegation.delegationId);
                         if (pmDelegation) {
                             pmDelegation.endIndex = index;
                         }
-                        
+
                         console.log('Delegation ended:', this.state.currentDelegation);
                         this.state.currentDelegation = null;
                     }
                 }
-                
+
                 // Track events within PM delegation context
                 if (this.state.currentDelegation && finalAgent.type === 'subagent') {
                     const pmDelegation = this.state.pmDelegations.get(this.state.currentDelegation.delegationId);
@@ -450,13 +477,13 @@ class AgentInference {
                         });
                     }
                 }
-                
+
                 // Store the inference result
                 this.state.eventAgentMap.set(index, finalAgent);
-                
+
                 // Update session agent tracking
                 this.state.sessionAgents.set(sessionId, finalAgent);
-                
+
                 // Debug first few inferences
                 if (index < 5) {
                     console.log(`Event ${index} agent inference:`, {
@@ -470,7 +497,7 @@ class AgentInference {
                 }
             } catch (error) {
                 console.error(`Error processing event ${index} for agent inference:`, error);
-                
+
                 // Set a default finalAgent if not already set due to error
                 if (!finalAgent) {
                     finalAgent = {
@@ -480,18 +507,22 @@ class AgentInference {
                         reason: 'error during processing'
                     };
                 }
-                
+
                 // Store the default inference for this event
                 this.state.eventAgentMap.set(index, finalAgent);
             }
         });
-        
+
+        // Identify orphan subagents after all events are processed
+        this.identifyOrphanSubagents(events);
+
         console.log('Agent inference processing complete. Results:', {
             total_events: events.length,
             inferred_agents: this.state.eventAgentMap.size,
             unique_sessions: this.state.sessionAgents.size,
             pm_delegations: this.state.pmDelegations.size,
-            agent_to_delegation_mappings: this.state.agentToDelegation.size
+            agent_to_delegation_mappings: this.state.agentToDelegation.size,
+            orphan_subagents: this.state.orphanSubagents.size
         });
     }
 
@@ -511,24 +542,24 @@ class AgentInference {
      */
     getInferredAgentForEvent(event) {
         const events = this.eventViewer.events;
-        
+
         // Try to find by exact reference first
         let eventIndex = events.indexOf(event);
-        
+
         // If exact match fails, try to find by timestamp or session_id + timestamp
         if (eventIndex === -1 && event.timestamp) {
-            eventIndex = events.findIndex(e => 
-                e.timestamp === event.timestamp && 
+            eventIndex = events.findIndex(e =>
+                e.timestamp === event.timestamp &&
                 e.session_id === event.session_id
             );
         }
-        
+
         // If we still can't find it, perform inline inference
         if (eventIndex === -1) {
             console.log('Agent inference: Could not find event in events array, performing inline inference');
             return this.inferAgentFromEvent(event);
         }
-        
+
         // Get cached inference or perform new inference
         let inference = this.getInferredAgent(eventIndex);
         if (!inference) {
@@ -536,7 +567,7 @@ class AgentInference {
             // Cache the result
             this.state.eventAgentMap.set(eventIndex, inference);
         }
-        
+
         return inference;
     }
 
@@ -580,6 +611,229 @@ class AgentInference {
         return this.state.agentToDelegation;
     }
 
+    /**
+     * Build hierarchical delegation tree structure
+     * @returns {Object} Tree structure with PM nodes and subagent children
+     */
+    buildDelegationHierarchy() {
+        // Get all PM delegations
+        const pmDelegations = this.getPMDelegations();
+        const events = this.eventViewer.events;
+        
+        // Build hierarchy tree
+        const hierarchy = {
+            mainPM: {
+                type: 'pm',
+                name: 'PM',
+                delegations: [],
+                ownEvents: [],
+                totalEvents: 0
+            },
+            impliedPM: {
+                type: 'pm_implied',
+                name: 'Implied PM',
+                delegations: [],
+                ownEvents: [],
+                totalEvents: 0
+            }
+        };
+        
+        // Process explicit PM delegations
+        for (const [delegationId, delegation] of pmDelegations) {
+            hierarchy.mainPM.delegations.push({
+                id: delegationId,
+                agentName: delegation.agentName,
+                taskContext: this.extractTaskContext(delegation.pmCall),
+                events: delegation.agentEvents,
+                startTime: delegation.timestamp,
+                endTime: delegation.endIndex ? events[delegation.endIndex]?.timestamp : null,
+                status: delegation.endIndex ? 'completed' : 'active'
+            });
+            hierarchy.mainPM.totalEvents += delegation.agentEvents.length;
+        }
+        
+        // Find PM's own events
+        events.forEach((event, index) => {
+            const inference = this.getInferredAgent(index);
+            if (inference && inference.type === 'main_agent') {
+                hierarchy.mainPM.ownEvents.push({
+                    eventIndex: index,
+                    event: event
+                });
+                hierarchy.mainPM.totalEvents++;
+            }
+        });
+        
+        // Find orphan subagent events
+        const orphanEvents = new Map();
+        events.forEach((event, index) => {
+            const inference = this.getInferredAgent(index);
+            if (inference && inference.type === 'subagent') {
+                // Check if this is part of any PM delegation
+                let isOrphan = true;
+                for (const [_, delegation] of pmDelegations) {
+                    if (delegation.agentEvents.some(e => e.eventIndex === index)) {
+                        isOrphan = false;
+                        break;
+                    }
+                }
+                
+                if (isOrphan) {
+                    const agentName = inference.agentName;
+                    if (!orphanEvents.has(agentName)) {
+                        orphanEvents.set(agentName, []);
+                    }
+                    orphanEvents.get(agentName).push({
+                        eventIndex: index,
+                        event: event,
+                        inference: inference
+                    });
+                }
+            }
+        });
+        
+        // Add orphan agents as implied PM delegations
+        for (const [agentName, agentEvents] of orphanEvents) {
+            hierarchy.impliedPM.delegations.push({
+                id: `implied_${agentName}`,
+                agentName: agentName,
+                taskContext: 'No explicit PM delegation',
+                events: agentEvents,
+                startTime: agentEvents[0].event.timestamp,
+                endTime: agentEvents[agentEvents.length - 1].event.timestamp,
+                status: 'completed'
+            });
+            hierarchy.impliedPM.totalEvents += agentEvents.length;
+        }
+        
+        return hierarchy;
+    }
+    
+    /**
+     * Extract task context from PM call
+     * @param {Object} pmCall - PM's Task tool call
+     * @returns {string} Task description
+     */
+    extractTaskContext(pmCall) {
+        if (!pmCall) return 'Unknown task';
+        
+        const params = pmCall.tool_parameters || pmCall.data?.tool_parameters || {};
+        return params.task || params.request || params.description || 'Task delegation';
+    }
+    
+    /**
+     * Identify orphan subagents (SubagentStart without PM Task delegation)
+     * @param {Array} events - All events to analyze
+     */
+    identifyOrphanSubagents(events) {
+        const ORPHAN_TIME_WINDOW = 5000; // 5 seconds to group orphans together
+        
+        // Check each SubagentStart event
+        for (const [agentName, startEvents] of this.state.subagentStartEvents) {
+            for (const startEvent of startEvents) {
+                const eventIndex = startEvent.eventIndex;
+                const timestamp = new Date(startEvent.timestamp).getTime();
+                
+                // Check if this SubagentStart has a corresponding PM Task delegation
+                let hasTaskDelegation = false;
+                
+                // Look for a Task tool call within a reasonable time window before this SubagentStart
+                for (let i = Math.max(0, eventIndex - 20); i < eventIndex; i++) {
+                    const prevEvent = events[i];
+                    if (!prevEvent) continue;
+                    
+                    const prevTimestamp = new Date(prevEvent.timestamp).getTime();
+                    const timeDiff = timestamp - prevTimestamp;
+                    
+                    // Check if this is a Task tool call within 10 seconds
+                    if (prevEvent.tool_name === 'Task' && timeDiff >= 0 && timeDiff < 10000) {
+                        const inference = this.state.eventAgentMap.get(i);
+                        if (inference && inference.agentName === agentName) {
+                            hasTaskDelegation = true;
+                            break;
+                        }
+                    }
+                }
+                
+                // If no Task delegation found, mark as orphan
+                if (!hasTaskDelegation) {
+                    this.state.orphanSubagents.set(eventIndex, {
+                        agentName: agentName,
+                        timestamp: startEvent.timestamp,
+                        sessionId: startEvent.sessionId,
+                        event: startEvent.event,
+                        groupingKey: null // Will be set by grouping logic
+                    });
+                }
+            }
+        }
+        
+        // Group orphan subagents by time proximity or session
+        this.groupOrphanSubagents(ORPHAN_TIME_WINDOW);
+    }
+    
+    /**
+     * Group orphan subagents that occur close together in time or same session
+     * @param {number} timeWindow - Time window in milliseconds for grouping
+     */
+    groupOrphanSubagents(timeWindow) {
+        const orphansList = Array.from(this.state.orphanSubagents.values())
+            .sort((a, b) => new Date(a.timestamp) - new Date(b.timestamp));
+        
+        let currentGroup = null;
+        let lastTimestamp = null;
+        
+        for (const orphan of orphansList) {
+            const timestamp = new Date(orphan.timestamp).getTime();
+            
+            // Check if this orphan should be in the same group
+            if (!currentGroup || 
+                (lastTimestamp && timestamp - lastTimestamp > timeWindow)) {
+                // Start a new group
+                currentGroup = `implied_pm_${orphan.sessionId}_${timestamp}`;
+            }
+            
+            orphan.groupingKey = currentGroup;
+            lastTimestamp = timestamp;
+        }
+    }
+    
+    /**
+     * Check if a subagent event is an orphan (no PM Task delegation)
+     * @param {number} eventIndex - Index of the event
+     * @returns {boolean} True if the event is from an orphan subagent
+     */
+    isOrphanSubagent(eventIndex) {
+        return this.state.orphanSubagents.has(eventIndex);
+    }
+    
+    /**
+     * Get orphan subagent context for an event
+     * @param {number} eventIndex - Index of the event  
+     * @returns {Object|null} Orphan context or null
+     */
+    getOrphanContext(eventIndex) {
+        return this.state.orphanSubagents.get(eventIndex) || null;
+    }
+    
+    /**
+     * Get all orphan subagent groups
+     * @returns {Map} Map of groupingKey -> array of orphan contexts
+     */
+    getOrphanGroups() {
+        const groups = new Map();
+        
+        for (const orphan of this.state.orphanSubagents.values()) {
+            const key = orphan.groupingKey;
+            if (!groups.has(key)) {
+                groups.set(key, []);
+            }
+            groups.get(key).push(orphan);
+        }
+        
+        return groups;
+    }
+
     /**
      * Get unique agent instances (one per agent type, consolidating multiple delegations)
      * This is used for the unique instance view in the agents tab
@@ -587,11 +841,11 @@ class AgentInference {
      */
     getUniqueAgentInstances() {
         const agentMap = new Map(); // agentName -> consolidated data
-        
+
         // Consolidate all PM delegations by agent name
         for (const [delegationId, delegation] of this.state.pmDelegations) {
             const agentName = delegation.agentName;
-            
+
             if (!agentMap.has(agentName)) {
                 // First delegation for this agent type
                 agentMap.set(agentName, {
@@ -607,7 +861,7 @@ class AgentInference {
                     delegationCount: 1
                 });
             }
-            
+
             // Add this delegation to the consolidated agent
             const agent = agentMap.get(agentName);
             agent.delegations.push({
@@ -619,14 +873,14 @@ class AgentInference {
                 endIndex: delegation.endIndex,
                 events: delegation.agentEvents
             });
-            
+
             if (delegation.pmCall) {
                 agent.pmCalls.push(delegation.pmCall);
             }
-            
+
             // Merge events from all delegations
             agent.allEvents = agent.allEvents.concat(delegation.agentEvents);
-            
+
             // Update consolidated metadata
             if (new Date(delegation.timestamp) < new Date(agent.firstTimestamp)) {
                 agent.firstTimestamp = delegation.timestamp;
@@ -634,11 +888,11 @@ class AgentInference {
             if (new Date(delegation.timestamp) > new Date(agent.lastTimestamp)) {
                 agent.lastTimestamp = delegation.timestamp;
             }
-            
+
             agent.totalEventCount += delegation.agentEvents.length;
             agent.delegationCount++;
         }
-        
+
         // Handle agents that appear without explicit PM delegation (implied PM)
         const events = this.eventViewer.events;
         for (let index = 0; index < events.length; index++) {
@@ -676,11 +930,11 @@ class AgentInference {
                 });
             }
         }
-        
+
         // Convert map to array and sort by first appearance (timestamp)
         const uniqueInstances = Array.from(agentMap.values())
             .sort((a, b) => new Date(a.firstTimestamp) - new Date(b.firstTimestamp));
-        
+
         console.log('Consolidated unique agents:', {
             total_unique_agents: uniqueInstances.length,
             agents: uniqueInstances.map(agent => ({
@@ -689,7 +943,14 @@ class AgentInference {
                 totalEvents: agent.totalEventCount
             }))
         });
-        
+
         return uniqueInstances;
     }
-}
\ No newline at end of file
+}
+
+// ES6 Module export
+export { AgentInference };
+export default AgentInference;
+
+// Make AgentInference globally available for dist/dashboard.js
+window.AgentInference = AgentInference;
