@@ -12,6 +12,11 @@ from .failure_learning import (
 from .kuzu_enrichment_hook import KuzuEnrichmentHook, get_kuzu_enrichment_hook
 from .kuzu_memory_hook import KuzuMemoryHook, get_kuzu_memory_hook
 from .kuzu_response_hook import KuzuResponseHook, get_kuzu_response_hook
+from .session_resume_hook import (
+    SessionResumeStartupHook,
+    get_session_resume_hook,
+    trigger_session_resume_check,
+)
 
 __all__ = [
     "BaseHook",
@@ -24,10 +29,13 @@ __all__ = [
     "KuzuMemoryHook",
     "KuzuResponseHook",
     "LearningExtractionHook",
+    "SessionResumeStartupHook",
     "get_failure_detection_hook",
     "get_fix_detection_hook",
     "get_kuzu_enrichment_hook",
     "get_kuzu_memory_hook",
     "get_kuzu_response_hook",
     "get_learning_extraction_hook",
+    "get_session_resume_hook",
+    "trigger_session_resume_check",
 ]
