@@ -13,7 +13,7 @@ chronological order for session replay and analysis.
 
 import json
 from dataclasses import asdict, dataclass, field
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from typing import Any, Dict, List, Optional, Set
 
@@ -204,7 +204,7 @@ class AgentSession:
         and metric updates.
         """
         if timestamp is None:
-            timestamp = datetime.utcnow().isoformat() + "Z"
+            timestamp = datetime.now(timezone.utc).isoformat() + "Z"
 
         # Categorize the event
         category = self._categorize_event(event_type, data)
@@ -338,7 +338,7 @@ class AgentSession:
                             event.timestamp.replace("Z", "+00:00")
                         )
                         tool_op.duration_ms = int((end - start).total_seconds() * 1000)
-                    except:
+                    except Exception:
                         pass
 
                     event.correlation_id = corr_id
@@ -393,7 +393,7 @@ class AgentSession:
                 self.metrics.session_duration_ms = int(
                     (end - start).total_seconds() * 1000
                 )
-            except:
+            except Exception:
                 pass
 
         # Finalize any pending delegations
@@ -448,7 +448,7 @@ class AgentSession:
         filepath = directory / filename
 
         # Save to file
-        with open(filepath, "w", encoding="utf-8") as f:
+        with filepath.open("w", encoding="utf-8") as f:
             json.dump(self.to_dict(), f, indent=2, ensure_ascii=False)
 
         return str(filepath)
@@ -531,6 +531,8 @@ class AgentSession:
 
         WHY: Enables analysis of historical sessions.
         """
-        with open(filepath, encoding="utf-8") as f:
+        with Path(filepath).open(
+            encoding="utf-8",
+        ) as f:
             data = json.load(f)
         return cls.from_dict(data)
