@@ -216,25 +216,41 @@ class AgentDiscoveryService:
             metadata = template_data.get("metadata", {})
             capabilities = template_data.get("capabilities", {})
 
+            # Handle capabilities as either dict or list
+            if isinstance(capabilities, list):
+                # If capabilities is a list (like in php-engineer.json), treat it as capabilities list
+                tools_list = template_data.get(
+                    "tools", []
+                )  # Look for tools at root level
+                model_value = template_data.get("model", "sonnet")
+            else:
+                # If capabilities is a dict, extract tools and model from it
+                tools_list = capabilities.get("tools", [])
+                model_value = capabilities.get("model", "sonnet")
+
             agent_info = {
                 "name": metadata.get("name", template_file.stem),
-                "description": metadata.get("description", "No description available"),
+                "description": metadata.get(
+                    "description",
+                    template_data.get("description", "No description available"),
+                ),
                 "type": template_data.get(
-                    "agent_type", metadata.get("category", "agent")
+                    "agent_type",
+                    metadata.get("category", template_data.get("category", "agent")),
                 ),  # Extract agent type
                 "version": template_data.get(
                     "agent_version",
                     template_data.get("version", metadata.get("version", "1.0.0")),
                 ),
-                "tools": capabilities.get("tools", []),
+                "tools": tools_list,
                 "specializations": metadata.get(
-                    "tags", []
-                ),  # Use tags as specializations
+                    "tags", template_data.get("tags", [])
+                ),  # Use tags as specializations, fallback to root-level tags
                 "file": template_file.name,
                 "path": str(template_file),
                 "file_path": str(template_file),  # Keep for backward compatibility
                 "size": template_file.stat().st_size,
-                "model": capabilities.get("model", "sonnet"),
+                "model": model_value,
                 "author": metadata.get("author", "unknown"),
             }
 
