@@ -3,6 +3,7 @@
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
+from claude_mpm.core.enums import OperationResult
 from claude_mpm.core.interfaces import AgentDeploymentInterface
 from claude_mpm.core.logger import get_logger
 
@@ -116,8 +117,10 @@ class RefactoredAgentDeploymentService(AgentDeploymentInterface):
             )
 
             # Ensure success field is present
-            if "success" not in results:
-                results["success"] = not bool(results.get("errors", []))
+            if OperationResult.SUCCESS.value not in results:
+                results[OperationResult.SUCCESS.value] = not bool(
+                    results.get("errors", [])
+                )
 
             self.logger.info(f"Deployment completed: {results.get('success', False)}")
             return results
@@ -125,7 +128,7 @@ class RefactoredAgentDeploymentService(AgentDeploymentInterface):
         except Exception as e:
             self.logger.error(f"Deployment failed: {e}", exc_info=True)
             return {
-                "success": False,
+                OperationResult.SUCCESS.value: False,
                 "error": str(e),
                 "deployed": [],
                 "updated": [],
@@ -235,7 +238,7 @@ class RefactoredAgentDeploymentService(AgentDeploymentInterface):
             # Build status information
             return {
                 "service_version": "refactored-1.0.0",
-                "status": "ready",
+                "status": OperationResult.SUCCESS,
                 "templates_dir": str(self.templates_dir),
                 "base_agent_path": str(self.base_agent_path),
                 "working_directory": str(self.working_directory),
@@ -255,7 +258,7 @@ class RefactoredAgentDeploymentService(AgentDeploymentInterface):
             self.logger.error(f"Failed to get deployment status: {e}", exc_info=True)
             return {
                 "service_version": "refactored-1.0.0",
-                "status": "error",
+                "status": OperationResult.ERROR,
                 "error": str(e),
             }
 
@@ -301,7 +304,7 @@ class RefactoredAgentDeploymentService(AgentDeploymentInterface):
         except Exception as e:
             self.logger.error(f"Async deployment failed: {e}", exc_info=True)
             return {
-                "success": False,
+                OperationResult.SUCCESS.value: False,
                 "error": str(e),
                 "deployed": [],
                 "updated": [],
