@@ -11,16 +11,15 @@ section extraction/updates, and version management.
 Uses python-frontmatter and mistune for markdown parsing as recommended.
 """
 
-import logging
-import os
 import re
-from datetime import datetime
-from typing import Any, Dict, List, Optional, Tuple
+from datetime import datetime, timezone
+from typing import Any, Dict, List, Optional
 
 import frontmatter
 import mistune
 import yaml
 
+from claude_mpm.core.logging_utils import get_logger
 from claude_mpm.core.unified_paths import get_path_manager
 from claude_mpm.models.agent_definition import (
     AgentDefinition,
@@ -34,7 +33,7 @@ from claude_mpm.services.memory.cache.shared_prompt_cache import SharedPromptCac
 
 from ..deployment.agent_versioning import AgentVersionManager
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class AgentManager:
@@ -157,7 +156,7 @@ class AgentManager:
         # Increment version if requested
         if increment_version:
             agent_def.metadata.increment_serial_version()
-            agent_def.metadata.last_updated = datetime.now()
+            agent_def.metadata.last_updated = datetime.now(timezone.utc)
 
         # Write back
         agent_path = self._find_agent_file(name)
@@ -235,7 +234,7 @@ class AgentManager:
         # Increment version
         if increment_version:
             agent_def.metadata.increment_serial_version()
-            agent_def.metadata.last_updated = datetime.now()
+            agent_def.metadata.last_updated = datetime.now(timezone.utc)
 
         # Write back
         return self.update_agent(name, {}, increment_version=False)
@@ -371,7 +370,7 @@ class AgentManager:
         title = title_match.group(1) if title_match else name.replace("-", " ").title()
 
         # Build definition
-        definition = AgentDefinition(
+        return AgentDefinition(
             name=name,
             title=title,
             file_path=file_path,
@@ -403,8 +402,6 @@ class AgentManager:
             raw_sections=sections,
         )
 
-        return definition
-
     def _extract_sections(self, content: str) -> Dict[str, str]:
         """Extract sections from markdown content."""
         sections = {}
@@ -425,10 +422,9 @@ class AgentManager:
                 # Start new section
                 current_section = header_match.group(1).strip()
                 current_content = []
-            else:
-                # Add to current section
-                if current_section:
-                    current_content.append(line)
+            # Add to current section
+            elif current_section:
+                current_content.append(line)
 
         # Save last section
         if current_section:
