@@ -16,7 +16,9 @@ from .interfaces import (  # Core dependency injection; Configuration management
     CacheEntry,
     HealthStatus,
     HookServiceInterface,
+    IAgentRecommender,
     IAgentRegistry,
+    IAutoConfigManager,
     ICacheService,
     IConfigurationManager,
     IConfigurationService,
@@ -31,6 +33,7 @@ from .interfaces import (  # Core dependency injection; Configuration management
     IServiceLifecycle,
     IStructuredLogger,
     ITemplateManager,
+    IToolchainAnalyzer,
     MemoryServiceInterface,
     ProjectAnalyzerInterface,
     ServiceType,
@@ -38,39 +41,68 @@ from .interfaces import (  # Core dependency injection; Configuration management
     TemplateRenderContext,
     TicketManagerInterface,
 )
+from .models import (  # Data models for services
+    AgentCapabilities,
+    AgentRecommendation,
+    ConfidenceLevel,
+    ConfigurationPreview,
+    ConfigurationResult,
+    DeploymentTarget,
+    Framework,
+    LanguageDetection,
+    ToolchainAnalysis,
+    ToolchainComponent,
+    ValidationResult,
+)
 
-__all__ = [
-    # Core interfaces
-    "IServiceContainer",
-    "ServiceType",
-    "IConfigurationService",
-    "IConfigurationManager",
-    "IAgentRegistry",
-    "AgentMetadata",
-    "IHealthMonitor",
-    "HealthStatus",
-    "IPromptCache",
-    "CacheEntry",
-    "ITemplateManager",
-    "TemplateRenderContext",
-    "IServiceFactory",
-    "IEventBus",
-    "IStructuredLogger",
-    "IServiceLifecycle",
-    "IErrorHandler",
-    "IPerformanceMonitor",
-    "ICacheService",
+__all__ = [  # noqa: RUF022 - Grouped by category with comments for clarity
     # Service interfaces
     "AgentDeploymentInterface",
-    "MemoryServiceInterface",
-    "HookServiceInterface",
-    "SocketIOServiceInterface",
-    "ProjectAnalyzerInterface",
-    "TicketManagerInterface",
-    # Registry
-    "InterfaceRegistry",
+    "AgentMetadata",
     # Base classes
     "BaseService",
-    "SyncBaseService",
+    "CacheEntry",
+    "HealthStatus",
+    "HookServiceInterface",
+    "IAgentRecommender",
+    "IAgentRegistry",
+    "IAutoConfigManager",
+    "ICacheService",
+    "IConfigurationManager",
+    "IConfigurationService",
+    "IErrorHandler",
+    "IEventBus",
+    "IHealthMonitor",
+    "IPerformanceMonitor",
+    "IPromptCache",
+    # Core interfaces
+    "IServiceContainer",
+    "IServiceFactory",
+    "IServiceLifecycle",
+    "IStructuredLogger",
+    "ITemplateManager",
+    "IToolchainAnalyzer",
+    # Registry
+    "InterfaceRegistry",
+    "MemoryServiceInterface",
+    "ProjectAnalyzerInterface",
+    "ServiceType",
     "SingletonService",
+    "SocketIOServiceInterface",
+    "SyncBaseService",
+    "TemplateRenderContext",
+    "TicketManagerInterface",
+    # Data models - Toolchain
+    "ConfidenceLevel",
+    "ToolchainComponent",
+    "LanguageDetection",
+    "Framework",
+    "DeploymentTarget",
+    "ToolchainAnalysis",
+    # Data models - Agent Configuration
+    "AgentCapabilities",
+    "AgentRecommendation",
+    "ConfigurationResult",
+    "ValidationResult",
+    "ConfigurationPreview",
 ]
