@@ -15,7 +15,6 @@ Features:
 """
 
 import fnmatch
-import logging
 import threading
 import time
 from dataclasses import dataclass, field
@@ -23,8 +22,9 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
 from claude_mpm.core.interfaces import ICacheService
+from claude_mpm.core.logging_utils import get_logger
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 @dataclass
