@@ -18,17 +18,15 @@ WHY indexed memory:
 
 import bisect
 import hashlib
-import mmap
-import os
 import pickle
 import re
 import time
 from collections import Counter, defaultdict
 from dataclasses import dataclass, field
-from datetime import datetime, timedelta
-from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from datetime import datetime, timedelta, timezone
+from typing import Any, Dict, List, Optional, Set, Tuple
 
-from ...core.cache import FileSystemCache, get_file_cache
+from ...core.cache import get_file_cache
 from ...core.logger import get_logger
 
 
@@ -215,7 +213,7 @@ class InvertedIndex:
             "doc_freqs": dict(self.doc_freqs),
             "doc_count": self.doc_count,
         }
-        with open(path, "wb") as f:
+        with path.open("wb") as f:
             pickle.dump(data, f)
 
     def load(self, path: Path):
@@ -223,7 +221,7 @@ class InvertedIndex:
         if not path.exists():
             return
 
-        with open(path, "rb") as f:
+        with path.open("rb") as f:
             data = pickle.load(f)
 
         self.index = defaultdict(set, {k: set(v) for k, v in data["index"].items()})
@@ -256,7 +254,7 @@ class BTreeIndex:
         self.index = [(k, id) for k, id in self.index if id != entry_id]
 
     def range_search(
-        self, min_key: Any = None, max_key: Any = None, limit: int = None
+        self, min_key: Any = None, max_key: Any = None, limit: Optional[int] = None
     ) -> List[str]:
         """Search for entries in key range.
 
@@ -366,8 +364,8 @@ class IndexedMemoryService:
         agent_id: str,
         content: str,
         category: str = "general",
-        tags: List[str] = None,
-        metadata: Dict[str, Any] = None,
+        tags: Optional[List[str]] = None,
+        metadata: Optional[Dict[str, Any]] = None,
     ) -> str:
         """Add a new memory entry.
 
@@ -390,7 +388,7 @@ class IndexedMemoryService:
             agent_id=agent_id,
             content=content,
             category=category,
-            timestamp=datetime.now(),
+            timestamp=datetime.now(timezone.utc),
             tags=tags or [],
             metadata=metadata or {},
         )
@@ -512,7 +510,7 @@ class IndexedMemoryService:
         start_time = time.time()
 
         # Calculate time range
-        now = datetime.now()
+        now = datetime.now(timezone.utc)
         if hours:
             min_time = now - timedelta(hours=hours)
         elif days:
@@ -565,7 +563,7 @@ class IndexedMemoryService:
 
     def _generate_id(self, agent_id: str, content: str) -> str:
         """Generate unique ID for memory entry."""
-        timestamp = datetime.now().isoformat()
+        timestamp = datetime.now(timezone.utc).isoformat()
         hash_input = f"{agent_id}:{content[:100]}:{timestamp}"
         return hashlib.md5(hash_input.encode()).hexdigest()[:12]
 
@@ -575,7 +573,7 @@ class IndexedMemoryService:
         self.text_index.save(self.data_dir / "text_index.pkl")
 
         # Save other indexes
-        with open(self.data_dir / "indexes.pkl", "wb") as f:
+        with Path(self.data_dir / "indexes.pkl").open("wb") as f:
             pickle.dump(
                 {
                     "memories": self.memories,
@@ -599,7 +597,7 @@ class IndexedMemoryService:
         # Load other indexes
         indexes_path = self.data_dir / "indexes.pkl"
         if indexes_path.exists():
-            with open(indexes_path, "rb") as f:
+            with indexes_path.open("rb") as f:
                 data = pickle.load(f)
 
             self.memories = data.get("memories", {})
