@@ -22,9 +22,8 @@ rather than aggressively removing content. Better to keep potentially useful
 information than lose important insights.
 """
 
-import os
 import re
-from datetime import datetime
+from datetime import datetime, timezone
 from difflib import SequenceMatcher
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
@@ -79,7 +78,7 @@ class MemoryOptimizer(LoggerMixin):
         self.config = config or Config()
         self.project_root = get_path_manager().get_project_root()
         # Use current working directory by default, not project root
-        self.working_directory = working_directory or Path(os.getcwd())
+        self.working_directory = working_directory or Path(Path.cwd())
         self.memories_dir = self.working_directory / ".claude-mpm" / "memories"
 
     def optimize_agent_memory(self, agent_id: str) -> Dict[str, Any]:
@@ -164,7 +163,7 @@ class MemoryOptimizer(LoggerMixin):
                     else 0
                 ),
                 "backup_created": str(backup_path),
-                "timestamp": datetime.now().isoformat(),
+                "timestamp": datetime.now(timezone.utc).isoformat(),
                 **optimization_stats,
             }
 
@@ -230,7 +229,7 @@ class MemoryOptimizer(LoggerMixin):
 
             return {
                 "success": True,
-                "timestamp": datetime.now().isoformat(),
+                "timestamp": datetime.now(timezone.utc).isoformat(),
                 "agents": results,
                 "summary": {
                     **total_stats,
@@ -545,7 +544,7 @@ class MemoryOptimizer(LoggerMixin):
 
         # Update timestamp
         content = "\n".join(content_lines)
-        timestamp = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+        timestamp = datetime.now(timezone.utc).strftime("%Y-%m-%d %H:%M:%S")
         return re.sub(
             r"<!-- Last Updated: .+ \| Auto-updated by: .+ -->",
             f"<!-- Last Updated: {timestamp} | Auto-updated by: optimizer -->",
@@ -561,7 +560,7 @@ class MemoryOptimizer(LoggerMixin):
         Returns:
             Path to backup file
         """
-        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
+        timestamp = datetime.now(timezone.utc).strftime("%Y%m%d_%H%M%S")
         backup_name = f"{memory_file.stem}_backup_{timestamp}{memory_file.suffix}"
         backup_path = memory_file.parent / backup_name
 
@@ -647,7 +646,7 @@ class MemoryOptimizer(LoggerMixin):
 
         return {
             "success": True,
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": datetime.now(timezone.utc).isoformat(),
             "agents_analyzed": len(agents_analysis),
             "agents": agents_analysis,
         }
