@@ -24,7 +24,7 @@ import json
 import re
 import shutil
 import subprocess
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
@@ -116,7 +116,7 @@ Generated by Claude MPM Archive Manager
 
         try:
             # Generate archive filename
-            timestamp = datetime.now().strftime("%Y-%m-%dT%H-%M-%S")
+            timestamp = datetime.now(timezone.utc).strftime("%Y-%m-%dT%H-%M-%S")
             archive_name = f"{file_path.name}.{timestamp}{file_path.suffix}"
             archive_file_path = self.archive_path / archive_name
 
@@ -130,7 +130,7 @@ Generated by Claude MPM Archive Manager
                 meta_data.update(
                     {
                         "original_path": str(file_path),
-                        "archived_at": datetime.now().isoformat(),
+                        "archived_at": datetime.now(timezone.utc).isoformat(),
                         "reason": reason or "Manual archive",
                         "file_size": file_path.stat().st_size,
                         "file_hash": self._calculate_file_hash(file_path),
@@ -152,7 +152,7 @@ Generated by Claude MPM Archive Manager
     def _calculate_file_hash(self, file_path: Path) -> str:
         """Calculate MD5 hash of file."""
         hasher = hashlib.md5()
-        with open(file_path, "rb") as f:
+        with file_path.open("rb") as f:
             for chunk in iter(lambda: f.read(4096), b""):
                 hasher.update(chunk)
         return hasher.hexdigest()
@@ -172,7 +172,9 @@ Generated by Claude MPM Archive Manager
                 logger.info(f"Removed old archive: {archive.name}")
 
         # Compress old archives
-        cutoff_compress = datetime.now() - timedelta(days=self.COMPRESS_AFTER_DAYS)
+        cutoff_compress = datetime.now(timezone.utc) - timedelta(
+            days=self.COMPRESS_AFTER_DAYS
+        )
         for archive in archives:
             if archive.suffix != ".gz":
                 mtime = datetime.fromtimestamp(archive.stat().st_mtime)
@@ -180,7 +182,9 @@ Generated by Claude MPM Archive Manager
                     self._compress_archive(archive)
 
         # Delete very old archives
-        cutoff_delete = datetime.now() - timedelta(days=self.DELETE_AFTER_DAYS)
+        cutoff_delete = datetime.now(timezone.utc) - timedelta(
+            days=self.DELETE_AFTER_DAYS
+        )
         for archive in archives:
             mtime = datetime.fromtimestamp(archive.stat().st_mtime)
             if mtime < cutoff_delete:
@@ -204,7 +208,7 @@ Generated by Claude MPM Archive Manager
         try:
             compressed_path = archive_path.with_suffix(archive_path.suffix + ".gz")
 
-            with open(archive_path, "rb") as f_in:
+            with archive_path.open("rb") as f_in:
                 with gzip.open(compressed_path, "wb") as f_out:
                     shutil.copyfileobj(f_in, f_out)
 
@@ -321,7 +325,7 @@ Generated by Claude MPM Archive Manager
             if archive_file.suffix == ".gz":
                 # Decompress first
                 with gzip.open(archive_file, "rb") as f_in:
-                    with open(target_path, "wb") as f_out:
+                    with target_path.open("wb") as f_out:
                         shutil.copyfileobj(f_in, f_out)
             else:
                 shutil.copy2(archive_file, target_path)
@@ -519,7 +523,7 @@ Generated by Claude MPM Archive Manager
     def review_documentation(self, check_git: bool = True) -> Dict:
         """Comprehensive documentation review with outdated detection."""
         report = {
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": datetime.now(timezone.utc).isoformat(),
             "files_reviewed": {},
             "outdated_sections": [],
             "synchronization_issues": [],
@@ -698,7 +702,7 @@ Generated by Claude MPM Archive Manager
         if changelog_path.exists():
             last_modified = self.get_file_last_modified(changelog_path)
             if last_modified:
-                days_old = (datetime.now() - last_modified).days
+                days_old = (datetime.now(timezone.utc) - last_modified).days
                 if days_old > 30:
                     issues.append(
                         {
@@ -800,7 +804,7 @@ Generated by Claude MPM Archive Manager
             # Check if file hasn't been updated in git for long time
             if file_report.get("last_git_update"):
                 last_update = datetime.fromisoformat(file_report["last_git_update"])
-                days_old = (datetime.now() - last_update).days
+                days_old = (datetime.now(timezone.utc) - last_update).days
                 if days_old > 90:
                     should_archive = True
                     archive_reason.append(f"No updates for {days_old} days")
@@ -913,7 +917,7 @@ Generated by Claude MPM Archive Manager
                 changelog_content = changelog_path.read_text()
                 if f"## [{current_version}]" not in changelog_content:
                     # Add new version section
-                    today = datetime.now().strftime("%Y-%m-%d")
+                    today = datetime.now(timezone.utc).strftime("%Y-%m-%d")
                     new_section = f"\n## [{current_version}] - {today}\n\n### Added\n\n### Changed\n\n### Fixed\n\n"
 
                     # Insert after header
@@ -981,7 +985,7 @@ Generated by Claude MPM Archive Manager
             last_updated = "Unknown"
             if report.get("last_git_update"):
                 last_date = datetime.fromisoformat(report["last_git_update"])
-                days_ago = (datetime.now() - last_date).days
+                days_ago = (datetime.now(timezone.utc) - last_date).days
                 last_updated = f"{days_ago} days ago"
 
             table.add_row(filename, status, str(issues), last_updated)
