@@ -18,7 +18,6 @@ to provide complete project lifecycle tracking.
 
 import os
 import platform
-import shutil
 import subprocess
 import sys
 import uuid
@@ -29,14 +28,11 @@ from typing import Any, Dict, List, Optional
 import yaml
 
 from claude_mpm.core.logger import get_logger
-from claude_mpm.core.unified_paths import get_project_root
 
 
 class ProjectRegistryError(Exception):
     """Base exception for project registry operations."""
 
-    pass
-
 
 class ProjectRegistry:
     """
@@ -73,7 +69,7 @@ class ProjectRegistry:
             self.registry_dir.mkdir(parents=True, exist_ok=True)
         except Exception as e:
             self.logger.error(f"Failed to create registry directory: {e}")
-            raise ProjectRegistryError(f"Cannot create registry directory: {e}")
+            raise ProjectRegistryError(f"Cannot create registry directory: {e}") from e
 
     def get_or_create_project_entry(self) -> Dict[str, Any]:
         """
@@ -102,14 +98,13 @@ class ProjectRegistry:
                 )
                 # Update existing entry with current session info
                 return self._update_existing_entry(existing_entry)
-            else:
-                self.logger.debug("Creating new project registry entry")
-                # Create new entry
-                return self._create_new_entry()
+            self.logger.debug("Creating new project registry entry")
+            # Create new entry
+            return self._create_new_entry()
 
         except Exception as e:
             self.logger.error(f"Failed to get or create project entry: {e}")
-            raise ProjectRegistryError(f"Registry operation failed: {e}")
+            raise ProjectRegistryError(f"Registry operation failed: {e}") from e
 
     def _find_existing_entry(self) -> Optional[Dict[str, Any]]:
         """
@@ -129,7 +124,9 @@ class ProjectRegistry:
             # Search all registry files
             for registry_file in self.registry_dir.glob("*.yaml"):
                 try:
-                    with open(registry_file, "r", encoding="utf-8") as f:
+                    with Path(registry_file).open(
+                        encoding="utf-8",
+                    ) as f:
                         data = yaml.safe_load(f) or {}
 
                     # Check if project_path matches
@@ -311,6 +308,7 @@ class ProjectRegistry:
                 capture_output=True,
                 text=True,
                 timeout=5,
+                check=False,
             )
 
             if result.returncode == 0:
@@ -324,6 +322,7 @@ class ProjectRegistry:
                         capture_output=True,
                         text=True,
                         timeout=5,
+                        check=False,
                     )
                     if result.returncode == 0:
                         git_info["branch"] = result.stdout.strip()
@@ -338,6 +337,7 @@ class ProjectRegistry:
                         capture_output=True,
                         text=True,
                         timeout=5,
+                        check=False,
                     )
                     if result.returncode == 0:
                         git_info["remote_url"] = result.stdout.strip()
@@ -352,6 +352,7 @@ class ProjectRegistry:
                         capture_output=True,
                         text=True,
                         timeout=5,
+                        check=False,
                     )
                     if result.returncode == 0:
                         git_info["last_commit"] = result.stdout.strip()
@@ -366,6 +367,7 @@ class ProjectRegistry:
                         capture_output=True,
                         text=True,
                         timeout=5,
+                        check=False,
                     )
                     if result.returncode == 0:
                         git_info["has_uncommitted"] = bool(result.stdout.strip())
@@ -491,7 +493,7 @@ class ProjectRegistry:
             # Remove internal fields before saving
             save_data = {k: v for k, v in data.items() if not k.startswith("_")}
 
-            with open(registry_file, "w", encoding="utf-8") as f:
+            with registry_file.open("w", encoding="utf-8") as f:
                 yaml.dump(
                     save_data, f, default_flow_style=False, sort_keys=False, indent=2
                 )
@@ -500,7 +502,7 @@ class ProjectRegistry:
 
         except Exception as e:
             self.logger.error(f"Failed to save registry data: {e}")
-            raise ProjectRegistryError(f"Failed to save registry: {e}")
+            raise ProjectRegistryError(f"Failed to save registry: {e}") from e
 
     def list_projects(self) -> List[Dict[str, Any]]:
         """
@@ -517,7 +519,9 @@ class ProjectRegistry:
         try:
             for registry_file in self.registry_dir.glob("*.yaml"):
                 try:
-                    with open(registry_file, "r", encoding="utf-8") as f:
+                    with Path(registry_file).open(
+                        encoding="utf-8",
+                    ) as f:
                         data = yaml.safe_load(f) or {}
                     projects.append(data)
                 except Exception as e:
@@ -553,7 +557,9 @@ class ProjectRegistry:
         try:
             for registry_file in self.registry_dir.glob("*.yaml"):
                 try:
-                    with open(registry_file, "r", encoding="utf-8") as f:
+                    with Path(registry_file).open(
+                        encoding="utf-8",
+                    ) as f:
                         data = yaml.safe_load(f) or {}
 
                     # Check last accessed time
