@@ -13,7 +13,7 @@ import asyncio
 import threading
 import time
 from collections import deque
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 from typing import Any, Dict, Set
 
@@ -211,7 +211,7 @@ class SocketIOServerCore:
             await self.site.start()
 
             self.running = True
-            self.stats["start_time"] = datetime.now()
+            self.stats["start_time"] = datetime.now(timezone.utc)
 
             self.logger.info(
                 f"Socket.IO server listening on http://{self.host}:{self.port}"
@@ -396,11 +396,10 @@ class SocketIOServerCore:
         # Add working directory endpoint
         async def working_directory_handler(request):
             """Handle GET /api/working-directory to provide current working directory."""
-            import os
             from pathlib import Path
 
             try:
-                working_dir = os.getcwd()
+                working_dir = Path.cwd()
                 home_dir = str(Path.home())
 
                 return web.json_response(
@@ -430,27 +429,26 @@ class SocketIOServerCore:
         # Add file reading endpoint for source viewer
         async def file_read_handler(request):
             """Handle GET /api/file/read for reading source files."""
-            import os
 
             file_path = request.query.get("path", "")
 
             if not file_path:
                 return web.json_response({"error": "No path provided"}, status=400)
 
-            abs_path = os.path.abspath(os.path.expanduser(file_path))
+            abs_path = Path(Path(file_path).resolve().expanduser())
 
             # Security check - ensure file is within the project
             try:
-                project_root = os.getcwd()
+                project_root = Path.cwd()
                 if not abs_path.startswith(project_root):
                     return web.json_response({"error": "Access denied"}, status=403)
             except Exception:
                 pass
 
-            if not os.path.exists(abs_path):
+            if not Path(abs_path).exists():
                 return web.json_response({"error": "File not found"}, status=404)
 
-            if not os.path.isfile(abs_path):
+            if not Path(abs_path).is_file():
                 return web.json_response({"error": "Not a file"}, status=400)
 
             try:
@@ -460,7 +458,9 @@ class SocketIOServerCore:
 
                 for encoding in encodings:
                     try:
-                        with open(abs_path, encoding=encoding) as f:
+                        with Path(abs_path).open(
+                            encoding=encoding,
+                        ) as f:
                             content = f.read()
                         break
                     except UnicodeDecodeError:
@@ -474,10 +474,10 @@ class SocketIOServerCore:
                 return web.json_response(
                     {
                         "path": abs_path,
-                        "name": os.path.basename(abs_path),
+                        "name": Path(abs_path).name,
                         "content": content,
                         "lines": len(content.splitlines()),
-                        "size": os.path.getsize(abs_path),
+                        "size": Path(abs_path).stat().st_size,
                     }
                 )
 
@@ -749,7 +749,9 @@ class SocketIOServerCore:
                 uptime_seconds = 0
                 if self.stats.get("start_time"):
                     uptime_seconds = int(
-                        (datetime.now() - self.stats["start_time"]).total_seconds()
+                        (
+                            datetime.now(timezone.utc) - self.stats["start_time"]
+                        ).total_seconds()
                     )
 
                 # Get active sessions from main server if available
@@ -766,7 +768,7 @@ class SocketIOServerCore:
                 heartbeat_data = {
                     "type": "system",
                     "subtype": "heartbeat",
-                    "timestamp": datetime.now().isoformat(),
+                    "timestamp": datetime.now(timezone.utc).isoformat(),
                     "source": "server",
                     "data": {
                         "uptime_seconds": uptime_seconds,
