@@ -64,18 +64,22 @@ class BaseFileLoader(ABC):
     def _read_file(self, path: Path, encoding: str = "utf-8") -> str:
         """Read file with proper error handling"""
         try:
-            with open(path, encoding=encoding) as f:
+            with Path(path).open(
+                encoding=encoding,
+            ) as f:
                 return f.read()
         except UnicodeDecodeError:
             # Try with different encodings
             for enc in ["latin-1", "cp1252", "utf-16"]:
                 try:
-                    with open(path, encoding=enc) as f:
+                    with Path(path).open(
+                        encoding=enc,
+                    ) as f:
                         self.logger.warning(
                             f"Read {path} with fallback encoding: {enc}"
                         )
                         return f.read()
-                except:
+                except (UnicodeDecodeError, OSError):
                     continue
             raise
 
@@ -185,8 +189,8 @@ class StructuredFileLoader(BaseFileLoader):
                 import tomli
 
                 return tomli.loads(content)
-            except ImportError:
-                raise ImportError("Neither toml nor tomli package is installed")
+            except ImportError as e:
+                raise ImportError("Neither toml nor tomli package is installed") from e
         except Exception as e:
             if context.strict:
                 raise
@@ -209,7 +213,7 @@ class StructuredFileLoader(BaseFileLoader):
 
         try:
             return json.loads(content)
-        except:
+        except (json.JSONDecodeError, ValueError):
             return {}
 
     def _process_includes(
@@ -411,7 +415,7 @@ class EnvironmentFileLoader(BaseFileLoader):
         if value.startswith(("[", "{")):
             try:
                 return json.loads(value)
-            except:
+            except (json.JSONDecodeError, ValueError):
                 pass
 
         # Comma-separated list
