@@ -12,7 +12,7 @@ import threading
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from dataclasses import dataclass, field
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from enum import Enum
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
@@ -216,7 +216,7 @@ class UnifiedConfigService:
                     source=str(source),
                     format=format,
                     context=context,
-                    loaded_at=datetime.now(),
+                    loaded_at=datetime.now(timezone.utc),
                     checksum=self._calculate_checksum(config),
                     hot_reload=hot_reload,
                     ttl=ttl,
@@ -254,9 +254,10 @@ class UnifiedConfigService:
             # Apply specified validators or use schema-defined ones
             if validators:
                 for validator_name in validators:
-                    if validator_name in self._validators:
-                        if not self._validators[validator_name](config, schema):
-                            return False
+                    if validator_name in self._validators and not self._validators[
+                        validator_name
+                    ](config, schema):
+                        return False
             else:
                 # Use schema to determine validators
                 return self._validate_schema(config, schema)
@@ -439,7 +440,7 @@ class UnifiedConfigService:
 
         path = Path(source)
         if path.exists():
-            with open(path) as f:
+            with path.open() as f:
                 return json.load(f)
 
         # Try to parse as JSON string
@@ -452,7 +453,7 @@ class UnifiedConfigService:
 
         path = Path(source)
         if path.exists():
-            with open(path) as f:
+            with path.open() as f:
                 return yaml.safe_load(f)
 
         # Try to parse as YAML string
@@ -476,7 +477,7 @@ class UnifiedConfigService:
             # Try to parse value
             try:
                 config[clean_key] = json.loads(value)
-            except:
+            except (json.JSONDecodeError, ValueError):
                 config[clean_key] = value
 
         return config
@@ -508,7 +509,7 @@ class UnifiedConfigService:
 
         path = Path(source)
         if path.exists():
-            with open(path) as f:
+            with path.open() as f:
                 return toml.load(f)
 
         return toml.loads(str(source))
@@ -563,9 +564,12 @@ class UnifiedConfigService:
         """Validate enum values"""
         properties = schema.get("properties", {})
         for key, value in config.items():
-            if key in properties and "enum" in properties[key]:
-                if value not in properties[key]["enum"]:
-                    return False
+            if (
+                key in properties
+                and "enum" in properties[key]
+                and value not in properties[key]["enum"]
+            ):
+                return False
         return True
 
     def _validate_schema(self, config: Dict[str, Any], schema: Dict) -> bool:
@@ -596,9 +600,13 @@ class UnifiedConfigService:
         """Validate unique values in arrays"""
         properties = schema.get("properties", {})
         for key, value in config.items():
-            if key in properties and properties[key].get("uniqueItems"):
-                if isinstance(value, list) and len(value) != len(set(map(str, value))):
-                    return False
+            if (
+                key in properties
+                and properties[key].get("uniqueItems")
+                and isinstance(value, list)
+                and len(value) != len(set(map(str, value)))
+            ):
+                return False
         return True
 
     def _validate_format(self, config: Dict[str, Any], schema: Dict) -> bool:
@@ -641,10 +649,13 @@ class UnifiedConfigService:
         """Recursively validate nested structures"""
         properties = schema.get("properties", {})
         for key, value in config.items():
-            if key in properties and isinstance(value, dict):
-                if "properties" in properties[key]:
-                    if not self._validate_schema(value, properties[key]):
-                        return False
+            if (
+                key in properties
+                and isinstance(value, dict)
+                and "properties" in properties[key]
+                and not self._validate_schema(value, properties[key])
+            ):
+                return False
         return True
 
     def _validate_cross_field(self, config: Dict[str, Any], schema: Dict) -> bool:
@@ -706,7 +717,7 @@ class UnifiedConfigService:
         """Check if cached configuration is still valid"""
         if metadata.ttl:
             expiry = metadata.loaded_at + metadata.ttl
-            if datetime.now() > expiry:
+            if datetime.now(timezone.utc) > expiry:
                 return False
         return True
 
@@ -742,7 +753,7 @@ class UnifiedConfigService:
                 result = handler(error, source, context)
                 if result is not None:
                     return result
-            except:
+            except Exception:
                 continue
 
         self.logger.error(f"Failed to load config from {source}: {error}")
