@@ -8,30 +8,30 @@ for developers working on the claude-mpm dashboard.
 
 import argparse
 import asyncio
+
+# Try to import Rich for enhanced output
+import importlib.util
 import json
 import signal
 import sys
 import time
 from dataclasses import dataclass, field
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
 import socketio
 
-# Try to import Rich for enhanced output
-try:
+if importlib.util.find_spec("rich"):
     from rich.console import Console
-    from rich.layout import Layout
-    from rich.live import Live
     from rich.panel import Panel
     from rich.table import Table
     from rich.text import Text
 
     RICH_AVAILABLE = True
     console = Console()
-except ImportError:
+else:
     RICH_AVAILABLE = False
     console = None
 
@@ -232,7 +232,7 @@ class SocketIODebugger:
 
     def _display_event(self, data: Dict[str, Any]):
         """Display an event based on current mode."""
-        timestamp = datetime.now().strftime("%H:%M:%S.%f")[:-3]
+        timestamp = datetime.now(timezone.utc).strftime("%H:%M:%S.%f")[:-3]
         event_type = data.get("type", "unknown")
         event_data = data.get("data", {})
 
@@ -266,7 +266,7 @@ class SocketIODebugger:
             "PostToolUse": "✅",
             "Error": "❌",
             "Warning": "⚠️",
-            "Info": "ℹ️",
+            "Info": "[INFO]️",
             "MemoryUpdate": "🧠",
             "ConfigChange": "⚙️",
         }
@@ -430,7 +430,7 @@ class SocketIODebugger:
             return
 
         try:
-            with open(self.output_file, "a") as f:
+            with self.output_file.open("a") as f:
                 f.write(json.dumps(data) + "\n")
         except Exception as e:
             self._log("error", f"Failed to write to file: {e}")
@@ -449,7 +449,7 @@ class SocketIODebugger:
         if self.quiet and level not in ["error", "critical"]:
             return
 
-        timestamp = datetime.now().strftime("%H:%M:%S")
+        timestamp = datetime.now(timezone.utc).strftime("%H:%M:%S")
 
         if RICH_AVAILABLE:
             styles = {
@@ -463,7 +463,7 @@ class SocketIODebugger:
             console.print(f"[{timestamp}] {message}", style=style)
         else:
             prefixes = {
-                "info": "ℹ️",
+                "info": "[INFO]️",
                 "success": "✅",
                 "warning": "⚠️",
                 "error": "❌",
