@@ -46,7 +46,9 @@ def load_json_safe(
     file_path = Path(file_path)
 
     try:
-        with open(file_path, encoding=encoding) as f:
+        with Path(file_path).open(
+            encoding=encoding,
+        ) as f:
             return json.load(f)
     except FileNotFoundError:
         logger.debug(f"JSON file not found: {file_path}")
@@ -85,7 +87,7 @@ def save_json_safe(
         if create_parents:
             file_path.parent.mkdir(parents=True, exist_ok=True)
 
-        with open(file_path, "w", encoding=encoding) as f:
+        with file_path.open("w", encoding=encoding) as f:
             json.dump(data, f, indent=indent, ensure_ascii=False)
         return True
     except Exception as e:
@@ -112,7 +114,9 @@ def load_yaml_safe(
     file_path = Path(file_path)
 
     try:
-        with open(file_path, encoding=encoding) as f:
+        with Path(file_path).open(
+            encoding=encoding,
+        ) as f:
             return yaml.safe_load(f) or default or {}
     except FileNotFoundError:
         logger.debug(f"YAML file not found: {file_path}")
@@ -149,7 +153,7 @@ def save_yaml_safe(
         if create_parents:
             file_path.parent.mkdir(parents=True, exist_ok=True)
 
-        with open(file_path, "w", encoding=encoding) as f:
+        with file_path.open("w", encoding=encoding) as f:
             yaml.safe_dump(data, f, default_flow_style=False, allow_unicode=True)
         return True
     except Exception as e:
