@@ -99,7 +99,9 @@ class ConfigurationManager:
 
         logger.debug(f"Loading JSON configuration from {file_path}")
         try:
-            with open(file_path, encoding="utf-8") as f:
+            with Path(file_path).open(
+                encoding="utf-8",
+            ) as f:
                 config = json.load(f)
             self._update_cache(file_path, config)
             return config
@@ -142,7 +144,9 @@ class ConfigurationManager:
 
         logger.debug(f"Loading YAML configuration from {file_path}")
         try:
-            with open(file_path, encoding="utf-8") as f:
+            with Path(file_path).open(
+                encoding="utf-8",
+            ) as f:
                 config = yaml.safe_load(f) or {}
             self._update_cache(file_path, config)
             return config
@@ -185,7 +189,9 @@ class ConfigurationManager:
 
         logger.debug(f"Loading TOML configuration from {file_path}")
         try:
-            with open(file_path, encoding="utf-8") as f:
+            with Path(file_path).open(
+                encoding="utf-8",
+            ) as f:
                 config = toml.load(f)
             self._update_cache(file_path, config)
             return config
@@ -242,7 +248,7 @@ class ConfigurationManager:
             # Create parent directories if needed
             file_path.parent.mkdir(parents=True, exist_ok=True)
 
-            with open(file_path, "w", encoding="utf-8") as f:
+            with file_path.open("w", encoding="utf-8") as f:
                 json.dump(config, f, indent=indent, sort_keys=sort_keys)
             logger.info(f"Configuration saved to {file_path}")
         except Exception as e:
@@ -279,7 +285,7 @@ class ConfigurationManager:
             # Create parent directories if needed
             file_path.parent.mkdir(parents=True, exist_ok=True)
 
-            with open(file_path, "w", encoding="utf-8") as f:
+            with file_path.open("w", encoding="utf-8") as f:
                 yaml.dump(
                     config,
                     f,
@@ -313,7 +319,7 @@ class ConfigurationManager:
             # Create parent directories if needed
             file_path.parent.mkdir(parents=True, exist_ok=True)
 
-            with open(file_path, "w", encoding="utf-8") as f:
+            with file_path.open("w", encoding="utf-8") as f:
                 toml.dump(config, f)
             logger.info(f"Configuration saved to {file_path}")
         except Exception as e:
